@@ -537,9 +537,14 @@ get_components_newdata <- function (object, newdata, n_samples, n_mcmc,
     # prepare the data for calculations
     newdataL <- if (!is.data.frame(newdata)) newdata[["newdataL"]] else newdata
     newdataE <- if (!is.data.frame(newdata)) newdata[["newdataE"]] else newdata
+    idVar <- object$model_info$var_names$idVar
+    time_var <- object$model_info$var_names$time_var
+    newdataL <- newdataL[order(newdataL[[idVar]], newdataL[[time_var]]), ]
     if (!object$model_info$CR_MS) {
-        idT <- newdataE[[idVar <- object$model_info$var_names$idVar]]
-        keep_last_row <- tapply(row.names(newdataE), factor(idT, unique(idT)), tail, 1L)
+        newdataE <- newdataE[order(newdataE[[idVar]], newdataE[[time_var]]), ]
+        idT <- newdataE[[idVar]]
+        idT <- factor(idT, unique(idT))
+        keep_last_row <- tapply(row.names(newdataE), idT, tail, 1L)
         newdataE <- newdataE[keep_last_row, ]
     }
     Data <- prepare_Data_preds(object, newdataL, newdataE)
